@@ -469,20 +469,6 @@ namespace glz
       }
    };
 
-   inline constexpr std::array<uint16_t, 256> char_escape_table = [] {
-      auto combine = [](const char chars[2]) -> uint16_t { return uint16_t(chars[0]) | (uint16_t(chars[1]) << 8); };
-
-      std::array<uint16_t, 256> t{};
-      t['\b'] = combine(R"(\b)");
-      t['\t'] = combine(R"(\t)");
-      t['\n'] = combine(R"(\n)");
-      t['\f'] = combine(R"(\f)");
-      t['\r'] = combine(R"(\r)");
-      t['\"'] = combine(R"(\")");
-      t['\\'] = combine(R"(\\)");
-      return t;
-   }();
-
    template <class T>
       requires str_t<T> || char_t<T>
    struct to<JSON, T>
@@ -544,7 +530,7 @@ namespace glz
                      return value ? value : "";
                   }
                   else {
-                     return value;
+                     return sv{value};
                   }
                }();
 
@@ -578,7 +564,7 @@ namespace glz
                      return *value.data() ? sv{value.data()} : "";
                   }
                   else {
-                     return value;
+                     return sv{value};
                   }
                }();
                const auto n = str.size();
@@ -1156,8 +1142,8 @@ namespace glz
             }
 
             using val_t = detail::iterator_second_type<T>; // the type of value in each [key, value] pair
-
-            if constexpr (not always_skipped<val_t>) {
+            constexpr bool write_member_functions = check_write_member_functions(Opts);
+            if constexpr (!always_skipped<val_t> && (write_member_functions || !is_member_function_pointer<val_t>)) {
                if constexpr (null_t<val_t> && Opts.skip_null_members) {
                   auto write_first_entry = [&](auto&& it) {
                      auto&& [key, entry_val] = *it;
@@ -1619,7 +1605,8 @@ namespace glz
             }
 
             // skip
-            if constexpr (always_skipped<val_t>) {
+            constexpr bool write_member_functions = check_write_member_functions(Opts);
+            if constexpr (always_skipped<val_t> || (!write_member_functions && is_member_function_pointer<val_t>)) {
                return;
             }
             else {
@@ -1821,7 +1808,9 @@ namespace glz
                      if constexpr (meta<T>::skip(reflect<T>::keys[I], mctx)) return;
                   }
 
-                  if constexpr (always_skipped<val_t>) {
+                  constexpr bool write_member_functions = check_write_member_functions(Opts);
+                  if constexpr (always_skipped<val_t> ||
+                                (!write_member_functions && is_member_function_pointer<val_t>)) {
                      return;
                   }
                   else {
@@ -2041,4 +2030,4 @@ namespace glz
 
 #if defined(_MSC_VER)
 #pragma warning(pop)
-#endif
\ No newline at end of file
+#endif
